@@ -18,6 +18,8 @@ lq.layers.QuantDense(64, kernel_constraint=lq.constraints.WeightClip(2.))
 ```
 """
 
+from typing import Any, Mapping
+
 import tensorflow as tf
 
 from larq import utils
@@ -31,16 +33,16 @@ class WeightClip(tf.keras.constraints.Constraint):
     to be between `[-clip_value, clip_value]`.
 
     # Arguments
-    clip_value: The value to clip incoming weights.
+        clip_value: The value to clip incoming weights.
     """
 
-    def __init__(self, clip_value=1):
+    def __init__(self, clip_value: float = 1):
         self.clip_value = clip_value
 
-    def __call__(self, x):
+    def __call__(self, x: tf.Tensor) -> tf.Tensor:
         return tf.clip_by_value(x, -self.clip_value, self.clip_value)
 
-    def get_config(self):
+    def get_config(self) -> Mapping[str, Any]:
         return {"clip_value": self.clip_value}
 
 
